@@ -17,5 +17,8 @@ class MailTemplateView(TemplateView):
 
     def get_context_data(self, id, **kwargs):
         context = super(MailTemplateView, self).get_context_data(**kwargs)
-        context['mail'] = Outbox().get(id)
+        mail = Outbox().get(id)
+        context['mail'] = mail
+        context['content_type'] = self.request.GET['content_type']
+        context['content'] = mail.body[self.request.GET['content_type']]
         return context
